Learn R Programming

nonlinearTseries (version 0.2.10)

corrMatrix: Returns the correlation sums stored in the corrDim object

Description

Returns the correlation sums stored in the corrDim object

Usage

corrMatrix(x)

Arguments

x

A corrDim object.

Value

The corrMatrix function returns the correlations matrix storing the correlation sums that have been computed for all the embedding dimensions.

See Also

corrDim