Learn R Programming

nonlinearTseries (version 0.2.10)

embeddingDims: Get the embedding dimensions used for compute a chaotic invariant.

Description

Get the embedding dimensions used for compute a chaotic invariant.

Usage

embeddingDims(x)

Arguments

x

An object containing all the information needed for the estimate.

Value

A numeric vector with the embedding dimensions used for compute a chaotic invariant.

References

H. Kantz and T. Schreiber: Nonlinear Time series Analysis (Cambridge university press)