Several chaotic invariants are estimated by using linear regression. This
function provides a common interface for the estimate of all these parameters
(see corrDim, dfa and maxLyapunov
for examples).
estimate(x, regression.range, do.plot, ...)An object containing all the information needed for the estimate.
Range of values on the x-axis on which the regression is performed.
Logical value. If TRUE (default value), a plot of the regression is shown.
Additional parameters.
An estimate of the proper chaotic invariant.
H. Kantz and T. Schreiber: Nonlinear Time series Analysis (Cambridge university press)