Learn R Programming

nonlinearTseries (version 0.2.10)

fixedMass: fixed mass

Description

fixed mass

Usage

fixedMass(x)

Arguments

x

A infDim object.

Value

A numeric vector representing the fixed mass vector used in the information dimension algorithm represented by the infDim object.

See Also

infDim