A 3-dimensional numeric vector indicating the starting point for the time series.
Default: c(-13, -14, 47).
time
The temporal interval at which the system will be generated.
Default: time=seq(0,50,by = 0.01).
do.plot
Logical value. If TRUE (default value), a plot of the
generated Lorenz system is shown.
Value
A list with four vectors named time, x, y
and z containing the time, the x-components, the
y-components and the z-components of the Lorenz system, respectively.
Details
The Lorenz system is a system of ordinary differential equations defined as:
$$\dot{x} = \sigma(y-x)$$
$$\dot{y} = \rho x-y-xz$$
$$\dot{z} = -\beta z + xy$$
The default selection for the system parameters (\(\sigma=10, \rho=28, \beta=8/3\)) is known to
produce a deterministic chaotic time series.
References
Strogatz, S.: Nonlinear dynamics and chaos: with applications
to physics, biology, chemistry and engineering (Studies in Nonlinearity)