Function for denoising a given time series using nonlinear analysis techniques.
nonLinearNoiseReduction(time.series, embedding.dim, radius)The original time series to denoise.
Integer denoting the dimension in which we shall embed the time.series.
The radius used to looking for neighbours in the phase space (see details).
A vector containing the denoised time series.
This function takes a given time series and denoises it. The denoising is achieved by averaging each Takens' vector in an m-dimensional space with his neighbours (time lag=1). Each neighbourhood is specified with balls of a given radius (max norm is used).
H. Kantz and T. Schreiber: Nonlinear Time series Analysis (Cambridge university press)