Learn R Programming

nonlinearTseries (version 0.2.10)

plotLocalScalingExp: Plot local scaling exponents

Description

Plots the local scaling exponents of the correlation sum or the average Shannon information (when computing information dimension).

Usage

plotLocalScalingExp(x, ...)

Arguments

x

An object containing all the information needed for the estimate of the chaotic invariant.

...

Additional graphical parameters.

References

H. Kantz and T. Schreiber: Nonlinear Time series Analysis (Cambridge university press)