Learn R Programming

nonlinearTseries (version 0.2.10)

radius: Get the radius of the neighborhoods used for the computations of a chaotic invariant.

Description

Get the radius of the neighborhoods used for the computations of a chaotic invariant.

Usage

radius(x)

Arguments

x

An object containing all the information needed for the estimate of the chaotic invariant.

Value

A numeric vector with the radius of the neighborhoods used for the computations of a chaotic invariant.

References

H. Kantz and T. Schreiber: Nonlinear Time series Analysis (Cambridge university press)