Tsay's test: test for nonlinearity against the null hypothesis that the time
series follows some AR process. This is a generalization of Keenan's test.
Usage
tsayTest(time.series, order)
Arguments
time.series
The original time.series.
order
Order used for the AR model.
Value
A list containing the results of the test, including:
test.stat: the F-squared test statistic
p.value.
order: order of the AR process used for testing.
References
Tsay, R. S. (1986), Nonlinearity test for time series, Biometrika,
73, 461-466.