powered by
Returns the correlation sums stored in the corrDim object
corrMatrix(x)
A corrDim object.
The corrMatrix function returns the correlations matrix storing the correlation sums that have been computed for all the embedding dimensions.
corrDim